var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _CircuitRelayTransportListener_instances, _CircuitRelayTransportListener_removeRelayPeer;
import { CustomEvent, EventEmitter } from '@libp2p/interfaces/events';
import { multiaddr } from '@multiformats/multiaddr';
import { PeerMap } from '@libp2p/peer-collections';
import { logger } from '@libp2p/logger';
const log = logger('libp2p:circuit-relay:transport:listener');
class CircuitRelayTransportListener extends EventEmitter {
    constructor(components) {
        super();
        _CircuitRelayTransportListener_instances.add(this);
        this.connectionManager = components.connectionManager;
        this.relayStore = components.relayStore;
        this.listeningAddrs = new PeerMap();
        // remove listening addrs when a relay is removed
        this.relayStore.addEventListener('relay:removed', (evt) => {
            __classPrivateFieldGet(this, _CircuitRelayTransportListener_instances, "m", _CircuitRelayTransportListener_removeRelayPeer).call(this, evt.detail);
        });
        // remove listening addrs when a peer disconnects
        this.connectionManager.addEventListener('peer:disconnect', (evt) => {
            __classPrivateFieldGet(this, _CircuitRelayTransportListener_instances, "m", _CircuitRelayTransportListener_removeRelayPeer).call(this, evt.detail.remotePeer);
        });
    }
    async listen(addr) {
        log('listen on %s', addr);
        const addrString = addr.toString().split('/p2p-circuit').find(a => a !== '');
        const ma = multiaddr(addrString);
        const relayConn = await this.connectionManager.openConnection(ma);
        if (!this.relayStore.hasReservation(relayConn.remotePeer)) {
            // addRelay calls transportManager.listen which calls this listen method
            await this.relayStore.addRelay(relayConn.remotePeer, 'configured');
            return;
        }
        if (this.listeningAddrs.has(relayConn.remotePeer)) {
            log('already listening on relay %p', relayConn.remotePeer);
            return;
        }
        this.listeningAddrs.set(relayConn.remotePeer, addr);
        this.dispatchEvent(new CustomEvent('listening'));
    }
    /**
     * Get fixed up multiaddrs
     *
     * NOTE: This method will grab the peers multiaddrs and expand them such that:
     *
     * a) If it's an existing /p2p-circuit address for a specific relay i.e.
     * `/ip4/0.0.0.0/tcp/0/ipfs/QmRelay/p2p-circuit` this method will expand the
     * address to `/ip4/0.0.0.0/tcp/0/ipfs/QmRelay/p2p-circuit/ipfs/QmPeer` where
     * `QmPeer` is this peers id
     * b) If it's not a /p2p-circuit address, it will encapsulate the address as a /p2p-circuit
     * addr, such when dialing over a relay with this address, it will create the circuit using
     * the encapsulated transport address. This is useful when for example, a peer should only
     * be dialed over TCP rather than any other transport
     */
    getAddrs() {
        return [...this.listeningAddrs.values()];
    }
    async close() {
    }
}
_CircuitRelayTransportListener_instances = new WeakSet(), _CircuitRelayTransportListener_removeRelayPeer = function _CircuitRelayTransportListener_removeRelayPeer(peerId) {
    const had = this.listeningAddrs.has(peerId);
    this.listeningAddrs.delete(peerId);
    if (had) {
        // Announce listen addresses change
        this.dispatchEvent(new CustomEvent('close'));
    }
};
export function createListener(options) {
    return new CircuitRelayTransportListener(options);
}
//# sourceMappingURL=listener.js.map